/***************************************************************************
 *   NGT (Neopontec Gaming Toolkit		      			   *
 *   Distributed under the terms of the GNU LGPL License		   *
 *   Copyright (C) 2005 by Hector Blanco de Frutos                         *
 *   hectorblanco@neopontec.com                                            *
 *   Refer to the LICENSE file to read the full license agreement          *
 ***************************************************************************/

/*************************************************************************** 
 * 			Engine base header											   *
 ***************************************************************************/
/*!
 	\file
 	Toolkit basic definitions header file
 */
 
#ifndef ENGINE_BASE_H_
#define ENGINE_BASE_H_


#include "../ngt.h"
#include "machine_gp2x.h"
#include <string>
	
	using namespace std;
	
	
// Machine targets definitions
// Generic: for Win, Linux, Mac ...
#define NGT_MACHINE_GENERIC 0
// for the GamePark Holdings GP2X console
#define NGT_MACHINE_GP2X 2



using namespace std;

//! NGT Engine main class
/*!
  This class provides the methodes and attributes to initialize the engine
  and work with its components.
*/
class NGT_Engine{
	public:
		// Video atributes
		//! Horizontal resolution
		int video_res_h;
		//! Vertical resolution
		int video_res_w;
		//! Screen depth (bits per pixel) 
		int video_bpp;
		
		// Input atributes
		//! Enable or disable joysticks
		/*!
		 	Enables or disables the joystick support.\n
		 	<ul>
		 	- POSSIBLE VALUES:\n
		 	-# 0: Disable using joysticks.
		 	-# 1: Enable using joysticks.
		 	</ul>
		 */
		int input_joy_enabled;
		
		//! Attribute to use when working with a joystick
		SDL_Joystick *joystick;
		
		//! Show or hide the mouse cursor
		/*!
		 	Show or hide the mouse cursor in the screen.\n
		 	- POSSIBLE VALUES:\n
		 	-# 0: Hide the mouse cursor.
		 	-# 1: Show the mouse cursor..
		 */	
		int input_show_cursor;
		
		// Audio attributes
		//! Sound frequency
		/*!
		 	Sets the frequency for the sound system (SDL_Mixer).\n
		 	Refer to SDL_Mixer documentation for accepted values.\n
		 */
		int audio_frequency;
		//! Sound buffer
		/*!
		 	Sets the size of the buffer used by SDL_Mixer.\n
		 	Refer to SDL_Mixer documentation for accepted values.\n
		 */
		int audio_buffer;
		//! Sound playback mode
		/*!
		 	Sets the playback mode used by SDL_Mixer.\n
		 	Refer to SDL_Mixer documentation for accepted values.\n
		 */
		int audio_mode;
		
		// Other atributes
		//! Target hardware
		/*!
		 	Specify the machine (hardware) in which the application/game
		 	is designed for.\n\n
		 	- POSSIBLE VALUES:\n
		 	-# NGT_MACHINE_GENERIC : Standard. Ideal for over 99% machines.\n
		 	-# NGT_MACHINE_GP2X : Specific for the GamePark Holdgings GP2X Portable Media Player.\n
		 */
		int machine_target;
		
		// Functions and methodes
		
		//! Initialize the Engine
		/*!
		 	This must be done before using any other function of the engine.
		 */
		void initialize(SDL_Surface *&surf);
		//! Finalize the Engine
		/*!
		 	This must be done before closing the app or the game to finalize all the susystems of the toolkit.
		 */
		void NGT_Engine::finalize();
		
	private:
		string version;
};

#endif /*ENGINE_BASE_H_*/
